.. :InstrumentXML:

InstrumentXML
=============

.. currentmodule:: InstrumentXML



.. autosummary::
   :nosignatures:

    InstrumentXML.parseXML
    InstrumentXML.createXMLString
    parseXML


	


InstrumentXML Object and Methods
--------------------------------


.. automodule:: InstrumentXML
   :members:


